@@ -61,6 +61,17 @@ class Tempo(object):
             if "next" not in metadata or metadata.get("count", 0) < metadata.get("limit", 0):
                 break
 
+    def _single(self, url, **params):
+        # Resolve parameters
+        url = self.BASE_URL + url
+        headers = { "Authorization": "Bearer {}".format(self._token) }
+
+        # Return a single result
+        response = requests.get(url, params=params, headers=headers)
+        response.raise_for_status()
+        data = response.json()
+        yield data
+
     def get_accounts(self):
         """
         Retrieve existing accounts as a dictionary.
@@ -150,6 +161,30 @@ class Tempo(object):
         params = { "from": date_from, "to": date_to, "limit": self.MAX_RESULTS }
         return self._list(url, **params)
 
+    def get_team_members(self, teamid):
+        """
+        Returns members for particular ```team```.
+        """
+
+        url = f"/teams/{teamid}/members"
+        return self._list(url)
+
+    def get_team_memberships(self, membershipid):
+        """
+        Returns members for particular ```team membership id```.
+        """
+
+        url = f"/team-memberships/{membershipid}"
+        return self._single(url)
+
+    def get_account_team_membership(self, teamid, accountid):
+        """
+        Returns the active team membership of a specific ```accountid``` in a specific  ```teamid```.
+        """
+
+        url = f"/teams/{teamid}/members/{accountid}"
+        return self._single(url)
+
     def get_user_schedule(self, date_from, date_to, user=None):
         """
         Returns user schedule inside ```date_from``` and ```date_to```,
